Config

Struct Config 

pub struct Config {
Show 17 fields pub args: Vec<String>, pub profile: String, pub package: Option<String>, pub bin: Option<String>, pub example: Option<String>, pub bench: Option<String>, pub test: Option<String>, pub bench_flag: String, pub samply_args: Option<String>, pub features: Vec<String>, pub no_default_features: bool, pub verbose: bool, pub quiet: bool, pub no_samply: bool, pub dry_run: bool, pub no_profile_inject: bool, pub list_targets: bool,
}
Configuration structure for the cargo-samply command.

This struct contains all the command-line options and arguments that can be passed to cargo-samply.

Examples

use cargo_samply::cli::Config;

let config = Config {
    args: vec!["--help".to_string()],
    profile: "samply".to_string(),
    package: None,
    bin: Some("my-binary".to_string()),
    example: None,
    bench: None,
    test: None,
    features: vec!["feature1".to_string(), "feature2".to_string()],
    no_default_features: false,
    verbose: false,
    quiet: false,
    no_samply: false,
    dry_run: false,
    no_profile_inject: false,
    bench_flag: "--bench".to_string(),
    samply_args: None,
    list_targets: false,
};

Fields

args: Vec<String>

Trailing arguments passed to the binary being profiled

profile: String

Build with the specified profile

package: Option<String>

Package to profile (in a workspace)

bin: Option<String>

Binary to run

example: Option<String>

Example to run

bench: Option<String>

Benchmark target to run (e.g. cargo samply --bench throughput)

test: Option<String>

Test target to run (e.g. cargo samply --test integration_test)

bench_flag: String

The flag to use when running the benchmark target

samply_args: Option<String>

Arguments to pass to samply (e.g. --samply-args="--rate 2000"). Use = so the full string is parsed as the value of --samply-args, even when it starts with --.

features: Vec<String>

Build features to enable

no_default_features: bool

Disable default features

verbose: bool

Print extra output to help debug problems

quiet: bool

Suppress all output except errors

no_samply: bool

Disable the automatic samply start

dry_run: bool

Print the build and run commands without executing them

no_profile_inject: bool

Do not modify Cargo.toml to add the samply profile

list_targets: bool

List all available targets in the workspace and exit